#[non_exhaustive]pub struct GetNotebookMetadataInputBuilder { /* private fields */ }Expand description
A builder for GetNotebookMetadataInput.
Implementations
Sourceimpl GetNotebookMetadataInputBuilder
impl GetNotebookMetadataInputBuilder
Sourcepub fn notebook_id(self, input: impl Into<String>) -> Self
pub fn notebook_id(self, input: impl Into<String>) -> Self
The ID of the notebook whose metadata is to be retrieved.
This field is required.Sourcepub fn set_notebook_id(self, input: Option<String>) -> Self
pub fn set_notebook_id(self, input: Option<String>) -> Self
The ID of the notebook whose metadata is to be retrieved.
Sourcepub fn get_notebook_id(&self) -> &Option<String>
pub fn get_notebook_id(&self) -> &Option<String>
The ID of the notebook whose metadata is to be retrieved.
Sourcepub fn build(self) -> Result<GetNotebookMetadataInput, BuildError>
pub fn build(self) -> Result<GetNotebookMetadataInput, BuildError>
Consumes the builder and constructs a GetNotebookMetadataInput.
Sourceimpl GetNotebookMetadataInputBuilder
impl GetNotebookMetadataInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetNotebookMetadataOutput, SdkError<GetNotebookMetadataError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetNotebookMetadataOutput, SdkError<GetNotebookMetadataError, HttpResponse>>
Sends a request with this input using the given client.